==> mathjax_2.7.0.orig.tar.xz: MathJax-2.7.0/unpacked/localization/ast/HelpDialog.js <==
/*************************************************************
 *
 *  MathJax/localization/ast/HelpDialog.js
 *
 *  Copyright (c) 2009-2016 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
MathJax.Localization.addTranslation("ast","HelpDialog",{
        version: "2.7.0",
        isLoaded: true,
        strings: {
          Help: "Ayuda de MathJax",
          MathJax: "*MathJax* ye una biblioteca JavaScript que permite a los autores de p\u00E1xines incluir espresiones matem\u00E1tiques nes sos p\u00E1xines web. Como llector, nun necesita facer nada pa qu'esto asoceda.",
          Browsers: "*Navegadores*: MathJax funciona con tolos navegadores modernos, incluyendo IE6+, Firefox 3+, Chrome 0.2+, Safari 2+, Opera 9.6+ y la mayor\u00EDa de los navegadores pa m\u00F3viles.",
          Menu: "*Men\u00FA matem\u00E1tiques*: MathJax amiesta un men\u00FA de contestu a les ecuaciones. Faiga clic col bot\u00F3n drechu, o Ctrl-clic, en cualquier espresi\u00F3n matem\u00E1tica pa ver el men\u00FA.",
          ShowMath: "*Ver f\u00F3rmula como* permite ver el c\u00F3digu de marques de la f\u00F3rmula pa que pueda copiase y apegase (como MathML o nel so formatu orixinal).",
          Settings: "*Configuraci\u00F3n* permite controlar diverses carauter\u00EDstiques de MathJax, como'l tama\u00F1u de les f\u00F3rmules, ya'l mecanismu que s'usa pa ver les ecuaciones.",
          Language: "*Llingua* permite seleicionar la llingua qu'usa MathJax pa los men\u00FAs y mensaxes d'avisu.",
          Zoom: "*Zoom de f\u00F3rmula*: Si tien dificultaes pa lleer una ecuaci\u00F3n, MathJax pue ampliala p'ayuda-y a que la vea meyor.",
          Accessibilty: "*Accesibilid\u00E1*: MathJax funciona autom\u00E1ticamente con llectores de pantalla pa facer les espresiones matem\u00E1tiques accesibles a les persones con problemes de visi\u00F3n.",
          Fonts: "*Tipograf\u00EDa*: MathJax usa ciertes fontes matem\u00E1tiques si tan instalaes nel ordenador; d'otra manera, usar\u00E1 fontes basaes na web. Anque nun ye necesario, si tien les fontes instalaes de mou llocal ayudar\u00E1 a componer la p\u00E1xina m\u00E1s r\u00E1pidamente. Suxerimos qu'instale les [fontes STIX](%1)."
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/ast/HelpDialog.js");

==> mathjax_2.7.3+dfsg.orig.tar.xz: MathJax-2.7.3/unpacked/localization/ast/HelpDialog.js <==
/*************************************************************
 *
 *  MathJax/localization/ast/HelpDialog.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
MathJax.Localization.addTranslation("ast","HelpDialog",{
        version: "2.7.3",
        isLoaded: true,
        strings: {
          Help: "Ayuda de MathJax",
          MathJax: "*MathJax* ye una biblioteca JavaScript que permite a los autores de p\u00E1xines incluir espresiones matem\u00E1tiques nes sos p\u00E1xines web. Como llector, nun necesita facer nada pa qu'esto asoceda.",
          Browsers: "*Navegadores*: MathJax funciona con tolos navegadores modernos, incluyendo IE6+, Firefox 3+, Chrome 0.2+, Safari 2+, Opera 9.6+ y la mayor\u00EDa de los navegadores pa m\u00F3viles.",
          Menu: "*Men\u00FA matem\u00E1tiques*: MathJax amiesta un men\u00FA de contestu a les ecuaciones. Faiga clic col bot\u00F3n drechu, o Ctrl-clic, en cualquier espresi\u00F3n matem\u00E1tica pa ver el men\u00FA.",
          ShowMath: "*Ver f\u00F3rmula como* permite ver el c\u00F3digu de marques de la f\u00F3rmula pa que pueda copiase y apegase (como MathML o nel so formatu orixinal).",
          Settings: "*Configuraci\u00F3n* permite controlar diverses carauter\u00EDstiques de MathJax, como'l tama\u00F1u de les f\u00F3rmules, ya'l mecanismu que s'usa pa ver les ecuaciones.",
          Language: "*Llingua* permite seleicionar la llingua qu'usa MathJax pa los men\u00FAs y mensaxes d'avisu.",
          Zoom: "*Zoom de f\u00F3rmula*: Si tien dificultaes pa lleer una ecuaci\u00F3n, MathJax pue ampliala p'ayuda-y a que la vea meyor.",
          Accessibilty: "*Accesibilid\u00E1*: MathJax funciona autom\u00E1ticamente con llectores de pantalla pa facer les espresiones matem\u00E1tiques accesibles a les persones con problemes de visi\u00F3n.",
          Fonts: "*Tipograf\u00EDa*: MathJax usa ciertes fontes matem\u00E1tiques si tan instalaes nel ordenador; d'otra manera, usar\u00E1 fontes basaes na web. Anque nun ye necesario, si tien les fontes instalaes de mou llocal ayudar\u00E1 a componer la p\u00E1xina m\u00E1s r\u00E1pidamente. Suxerimos qu'instale les [fontes STIX](%1).",
          CloseDialog: "Zarrar el di\u00E1logu d'ayuda"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/ast/HelpDialog.js");
